@@ -266,6 +266,7 @@ class AdvancedEmergeDialog:
                 removelist.append(item[1:])
             else:
                 removelist.append('-' + item)
+        #debug.dprint("ADVEMERGE: on_package_use_commit(); addlist:%s,\n removelist:%s" %(str(addlist), str(removelist)))
         okay = db.userconfigs.set_user_config('USE', name=self.package.full_name, add=addlist,
                                                                 remove=removelist, callback=self.reload, parent_window = self.window )
         self.version_changed(button_widget)
@@ -299,7 +300,7 @@ class AdvancedEmergeDialog:
             removelist = ["-" + keyword]
         verInfo = self.current_verInfo
         ebuild = verInfo["name"]
-        okay = db.userconfigs.set_user_config('package.keywords', ebuild=ebuild, add=addlist, remove=removelist, callback=self.reload)
+        okay = db.userconfigs.set_user_config('KEYWORDS', ebuild=ebuild, add=addlist, remove=removelist, callback=self.reload)
     
     #------------------------------------------
     # Support function definitions start here
