@@ -32,6 +32,8 @@ print "PORTAGELIB: id initialized to ", id
 from sys import exit, stderr
 import os, thread
 from gettext import gettext as _
+from itertools import izip
+
 
 from porthole.utils import debug
 from porthole.utils.utils import  is_root
@@ -72,123 +74,6 @@ thread_id = thread.get_ident()
 if is_root(): # then import some modules and run it directly
     import set_config
 
-def get_user_config(file, name=None, ebuild=None):
-    """ depricated function. this is now part of the db.user_configs module
-    Function for parsing package.use, package.mask, package.unmask
-    and package.keywords.
-    
-    Returns /etc/portage/<file> as a dictionary of ebuilds, with
-    dict[ebuild] = list of flags.
-    If name is given, it will be parsed for ebuilds with xmatch('match-all'),
-    and only those ebuilds will be returned in dict.
-    
-    If <ebuild> is given, it will be matched against each line in <file>.
-    For package.use/keywords, a list of applicable flags is returned.
-    For package.mask/unmask, a list containing the matching lines is returned.
-    """
-    debug.dprint("PORTAGELIB: DEPRICATED FUNCTION! get_user_config('%s'), PLEASE update the code calling this function to use db.userconfigs.get_user_config()" % file)
-    maskfiles = ['package.mask', 'package.unmask']
-    otherfiles = ['package.use', 'package.keywords']
-    package_files = otherfiles + maskfiles
-    if file not in package_files:
-        debug.dprint(" * PORTAGELIB: get_user_config(): unsupported config file '%s'" % file)
-        return None
-    filename = '/'.join([portage_const.USER_CONFIG_PATH, file])
-    if not os.access(filename, os.R_OK):
-        debug.dprint(" * PORTAGELIB: get_user_config(): no read access on '%s'?" % file)
-        return {}
-    configfile = open(filename, 'r')
-    configlines = configfile.readlines()
-    configfile.close()
-    config = [line.split() for line in configlines]
-    # e.g. [['media-video/mplayer', 'real', '-v4l'], [app-portage/porthole', 'sudo']]
-    dict = {}
-    if ebuild is not None:
-        result = []
-        for line in config:
-            if line and line[0]:
-                if line[0].startswith('#'):
-                    continue
-                match = xmatch('match-list', line[0], mylist=[ebuild])
-                if match:
-                    if file in maskfiles: result.extend(line[0]) # package.mask/unmask
-                    else: result.extend(line[1:]) # package.use/keywords
-        return result
-    if name:
-        target = xmatch('match-all', name)
-        for line in config:
-            if line and line[0]:
-                if line[0].startswith('#'):
-                    continue
-                ebuilds = xmatch('match-all', line[0])
-                for ebuild in ebuilds:
-                    if ebuild in target:
-                        dict[ebuild] = line[1:]
-    else:
-        for line in config:
-            if line and line[0]:
-                if line[0].startswith('#'):
-                    continue
-                ebuilds = xmatch('match-all', line[0])
-                for ebuild in ebuilds:
-                    dict[ebuild] = line[1:]
-    return dict
-
-def set_user_config( file, name='', ebuild='', add='', remove='', callback=None):
-    """depricated function. this is now part of the db.user_configs module
-    Function for parsing package.use, package.mask, package.unmask
-    and package.keywords.
-
-    Adds <name> or '=' + <ebuild> to <file> with flags <add>.
-    If an existing entry is found, items in <remove> are removed and <add> is added.
-    
-    If <name> and <ebuild> are not given then lines starting with something in
-    remove are removed, and items in <add> are added as new lines.
-    """
-    debug.dprint("PORTAGELIB: DEPRICATED FUNCTION! set_user_config(); depricated update calling code to use the db.user_configs module")
-    command = ''
-    maskfiles = ['package.mask', 'package.unmask']
-    otherfiles = ['package.use', 'package.keywords']
-    package_files = otherfiles + maskfiles
-    if file not in package_files:
-        debug.dprint(" * PORTAGELIB: set_user_config(); unsupported config file '%s'" % file)
-        return False
-    if isinstance(add, list):
-        add = ' '.join(add)
-    if isinstance(remove, list):
-        remove = ' '.join(remove)
-    config_path = portage_const.USER_CONFIG_PATH
-    if not os.access(config_path, os.W_OK):
-        commandlist = [config.Prefs.globals.su, '"python', config.Prefs.DATA_PATH + 'backends/set_config.py -d -f %s' %file]
-        if name != '':
-            commandlist.append('-n %s' %name)
-        if ebuild != '':
-            commandlist.append('-e %s' %ebuild)
-        if add != '':
-            items = add.split()
-            for item in items:
-                commandlist.append('-a %s' % item)
-        if remove != '':
-            items = remove.split()
-            for item in items:
-                commandlist.append('-r %s' % item)
-        command = ' '.join(commandlist) + '"'
-        debug.dprint(" * PORTAGELIB: set_user_config(); command = %s" %command )
-        if not callback: callback = reload_portage
-        app = SimpleTerminal(command, False, dprint_output='SET_USER_CONFIG CHILD APP: ', callback=Dispatcher(callback))
-        app._run()
-    else:
-        add = add.split()
-        remove = remove.split()
-        set_config.set_user_config(file, name, ebuild, add, remove)
-        if callback: callback()
-        else: reload_portage()
-    # This is slow, but otherwise portage doesn't notice the change.
-    #reload_portage()
-    # Note: could perhaps just update portage.settings.
-    # portage.settings.pmaskdict, punmaskdict, pkeywordsdict, pusedict
-    # or portage.portdb.mysettings ?
-    return True
 
 def get_make_conf(want_linelist=False, savecopy=False):
     """
@@ -201,7 +86,7 @@ def get_make_conf(want_linelist=False, savecopy=False):
     If savecopy is true, a copy of make.conf is saved in make.conf.bak.
     """
     debug.dprint("PORTAGELIB: get_make_conf()")
-    file = open(portage_const.MAKE_CONF_FILE, 'r')
+    file = open(os.path.join(portage.root, portage_const.MAKE_CONF_FILE), 'r')
     if savecopy:
         file2 = open(portage_const.MAKE_CONF_FILE + '.bak', 'w')
         file2.write(file.read())
@@ -257,8 +142,7 @@ def set_make_conf(property, add='', remove='', replace='', callback=None):
         remove = ' '.join(remove)
     if isinstance(replace, list):
         replace = ' '.join(replace)
-    config_path = portage_const.USER_CONFIG_PATH
-    if not os.access(portage_const.MAKE_CONF_FILE, os.W_OK):
+    if not os.access(os.path.join(portage.root, portage_const.MAKE_CONF_FILE), os.W_OK):
         command = (config.Prefs.globals.su + ' "python ' + config.Prefs.DATA_PATH + 'backends/set_config.py -d -f %s ' %file)
         command = (command + '-p %s ' % property)
         if add != '':
@@ -280,7 +164,7 @@ def set_make_conf(property, add='', remove='', replace='', callback=None):
     #reload_portage()
     # Note: could perhaps just update portage.settings.
     # portage.settings.pmaskdict, punmaskdict, pkeywordsdict, pusedict
-    # or portage.portdb.mysettings ?
+    # or portage.portdb.settings ?
     return True
 
 def get_virtuals():
@@ -466,21 +350,33 @@ def get_versions(full_name, include_masked = True):
 def get_hard_masked(full_name):
     full_name = str(full_name)
     hardmasked = []
-    try:
-        for x in settings.portdb.mysettings.pmaskdict[full_name]:
-            m = xmatch("match-all",x)
-            for n in m:
-                if n not in hardmasked: hardmasked.append(n)
+    try: # newer portage
+        pmaskdict = settings.portdb.settings.pmaskdict[full_name]
+    except AttributeError: # older portage
+        try:
+            pmaskdict = settings.portdb.mysettings.pmaskdict[full_name]
+        except KeyError:
+            pmaskdict = {}
     except KeyError:
-        pass
+        pmaskdict = {}
+    for x in pmaskdict:
+        m = xmatch("match-all",x)
+        for n in m:
+            if n not in hardmasked: hardmasked.append(n)
     hard_masked_nocheck = hardmasked[:]
-    try:
-        for x in settings.portdb.mysettings.punmaskdict[full_name]:
-            m = xmatch("match-all",x)
-            for n in m:
-                while n in hardmasked: hardmasked.remove(n)
+    try: # newer portage
+        punmaskdict = settings.portdb.settings.punmaskdict[full_name]
+    except AttributeError: # older portage
+        try:
+            punmaskdict = settings.portdb.mysettings.punmaskdict[full_name]
+        except KeyError:
+            punmaskdict = {}
     except KeyError:
-        pass
+        punmaskdict = {}
+    for x in punmaskdict:
+        m = xmatch("match-all",x)
+        for n in m:
+            while n in hardmasked: hardmasked.remove(n)
     return hard_masked_nocheck, hardmasked
 
 
@@ -526,7 +422,7 @@ def get_best_ebuild(full_name):
     return xmatch("bestmatch-visible",str(full_name)) # no unicode
 
 def get_dep_ebuild(dep):
-    """progreesively checks for available ebuilds that match the dependency.
+    """progresively checks for available ebuilds that match the dependency.
     returns what it finds as up to three options."""
     #debug.dprint("PORTAGELIB: get_dep_ebuild(); dep = " + dep)
     best_ebuild = keyworded_ebuild = masked_ebuild = ''
@@ -554,16 +450,29 @@ def get_archlist():
             #~ list.remove(entry)
     #~ return list
 
+
+def get_masking_status(ebuild):
+    return portage.getmaskingstatus(ebuild)
+
+
 def get_masking_reason(ebuild):
     """Strips trailing \n from, and returns the masking reason given by portage"""
     reason, location = portage.getmaskingreason(ebuild, settings=settings.settings, portdb=settings.portdb,  return_location=True)
-    if not reason: return _('No masking reason given')
+    if not reason:
+        reason =  _('No masking reason given.')
+        status =  get_masking_status(ebuild)
+        if 'profile' in status:
+            reason = _("Masked by the current profile.")
+            status.remove('profile')
+        if status:
+            reason += " from " + ', '.join(status)
     if location != None:
         reason += "in file: " + location
     if reason.endswith("\n"):
         reason = reason[:-1]
     return reason
 
+
 def get_size(mycpv):
     """ Returns size of package to fetch. """
     #This code to calculate size of downloaded files was taken from /usr/bin/emerge - BB
@@ -573,13 +482,15 @@ def get_size(mycpv):
     myebuild = settings.portdb.findname(mycpv)
     pkgdir = os.path.dirname(myebuild)
     mf = manifest.Manifest(pkgdir, settings.settings["DISTDIR"])
-    #debug.dprint( "PORTAGELIB: get_size; Attempting to get fetchlist")
+    final_use, use_expand_hidden, usemasked, useforced = get_cpv_use(mycpv)
+    #debug.dprint( "PORTAGELIB: get_size; Attempting to get fetchlist final use= " + str(final_use))
     try:
         if portage.VERSION >= '2.1.6':# newer portage
-            fetchlist = settings.portdb.getFetchMap(mycpv) 
+            fetchlist = settings.portdb.getFetchMap(mycpv, set(final_use)) 
         else:
             debug.dprint( "PORTAGELIB: get_size; Trying old fetchlist call")
             fetchlist = settings.portdb.getfetchlist(mycpv, mysettings=settings.settings, all=True)[1]
+        #debug.dprint( "PORTAGELIB: get_size; fetchlist= " +str(fetchlist))
         #debug.dprint( "PORTAGELIB: get_size; mf.getDistfilesSize()")
         mysum[0] = mf.getDistfilesSize(fetchlist)
         mystr = str(mysum[0]/1024)
@@ -663,9 +574,11 @@ def get_overlay(cpv):
     return ovl
 
 def get_overlay_name(ovl):
-    if ovl in settings.repos:
-        return settings.repos[ovl]
-    return "????"
+    try: # new upcoming portage function
+        name = settings.portdb.getRepositoryName(ovl)
+    except:  # Fallback method
+        name =  settings.repos.get(ovl)
+    return name or "????"
 
 def get_path(cpv):
     """Returns a path to the specified category/package-version"""
@@ -743,6 +656,7 @@ def get_installed_list():
 def get_installed_ebuild_path(fullname):
     return settings.trees[settings.settings["ROOT"]]["vartree"].getebuildpath(fullname)
 
+
 class PortageSettings:
     def __init__(self):
         # declare some globals
@@ -750,11 +664,8 @@ class PortageSettings:
         self.virtuals = self.keys = self.UseFlagDict = None
         if PORTAGE22: # then use the imported module
             self.my_load_emerge_config = _load_emerge_config
-        else: # use the one copied from the non importable emerge
+        else: # use the one copied from the non import-able emerge
             self.my_load_emerge_config = self.load_emerge_config
-        #self.settings, self.trees, self.mtimedb = self.load_emerge_config()
-        #self.portdb = self.trees[self.settings["ROOT"]]["porttree"].dbapi
-        #self.root_config = self.trees[self.settings["ROOT"]]["root_config"]
         self.reset()
 
     def reset_use_flags(self):
@@ -802,6 +713,7 @@ class PortageSettings:
 
     def create_repos(self):
         # reverse the treemap's key:data for easy name lookup
+        # until the new getRepositoryName() is fully available.
         t = self.portdb.treemap
         n = {}
         for x in t.keys():
