@@ -26,6 +26,7 @@ from gettext import gettext as _
 from porthole.utils.utils import is_root
 from porthole.utils import debug
 from porthole.sterminal import SimpleTerminal
+from porthole.privilege import controller as privileges
 
 
 app = None
@@ -75,9 +76,13 @@ def enable_plugin():
         return False
     debug.dprint(plugin_name + " enable_plugin: generating new menuitem")
     if is_root():
-        menuitem1 = manager.new_menuitem(_("Profuse (root mode)"))
+        menuitem1 = manager.new_menuitem(_("Profuse"))
         debug.dprint(plugin_name + " enabling plugin to run_as_user user='root'")
         menuitem1.connect("activate", run_as_user)
+    elif privileges.can_su:
+        menuitem1 = manager.new_menuitem(_("Profuse"))
+        debug.dprint(plugin_name + " enabling plugin to run_as_root, user='non-root'")
+        menuitem1.connect("activate", run_as_root)
     else:
         menuitem1 = manager.new_menuitem(_("Profuse (user mode)"))
         debug.dprint(plugin_name + " enabling plugin to run_as_user, user='non-root'")
@@ -100,20 +105,24 @@ def disable_plugin():
     enabled = False
 
 event_table = {
-	"load" : new_instance,
-	"reload" : new_instance,
-	"unload" : destroy_instance,
-	"enable" : enable_plugin,
-	"disable" : disable_plugin
+    "load" : new_instance,
+    "reload" : new_instance,
+    "unload" : destroy_instance,
+    "enable" : enable_plugin,
+    "disable" : disable_plugin
 }
 
 def run_as_root(*args):
-	global app, command, prefs
-	app = SimpleTerminal(config.Prefs.globals.su + ' ' + command, False)
-	app._run()
+    global app, command, prefs
+    if privileges.can_su:
+        app = SimpleTerminal(command, True, dprint_output='Profuse Plug-in;')
+        app._run()
+    else:
+        app = SimpleTerminal(config.Prefs.globals.su + ' ' +command, True, dprint_output='Profuse Plug-in;')
+        app._run()
 
 def run_as_user(*args):
-	global app, command
-	app = SimpleTerminal(command, False)
-	app._run()
+    global app, command
+    app = SimpleTerminal(command, False)
+    app._run()
 
