@@ -21,3 +21,6 @@
     along with this program; if not, write to the Free Software
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 '''
+__all__ = ['category', 'changelog', 'commontreeview', 'depends', 'helpers', 'highlight',
+    'lazyview', 'list', 'markup', 'menus', 'models', 'package', 'sorts']
+    
